@@ -53,6 +53,9 @@
 #  include <rexx.h>
 # endif
 # if defined(USE_OOREXX)
+#  if defined(OOREXX_40)
+#   define OOREXX_COMPATIBILITY 1
+#  endif
 #  include <rexx.h>
 # endif
 # if defined(USE_REXXTRANS)
@@ -97,6 +100,9 @@ typedef CHAR *PCH;
 #  include <rexx.h>
 # endif
 # if defined(USE_OOREXX)
+#  if defined(OOREXX_40)
+#   define OOREXX_COMPATIBILITY 1
+#  endif
 #  include <rexx.h>
 # endif
 # if defined(USE_QUERCUS)
@@ -428,6 +434,79 @@ typedef CHAR *PCH;
 # define RS_ARG7_TYPE         short *
 # define RS_ARG8_TYPE         PRXSTRING
 
+/*
+ * The following #defines are for the broken ooRexx 4.x legacy API
+ */
+#elif defined(OOREXX_40) && defined(USE_OOREXX)
+#ifndef APIRET
+# define APIRET               size_t
+#endif
+#ifndef APIENTRY
+# define APIENTRY             REXXENTRY
+#endif
+typedef char CHAR;
+typedef short int SHORT;
+typedef unsigned long ULONG;
+typedef long LONG;
+# define RXSTRING_STRPTR_TYPE  char *
+# define RFH_RETURN            size_t REXXENTRY
+# define RFH_RETURN_TYPE       size_t
+# define RFH_ARG0_TYPE         CONSTANT_STRING
+# define RFH_ARG1_TYPE         size_t
+# define RFH_ARG2_TYPE         PCONSTRXSTRING
+# define RFH_ARG3_TYPE         CONSTANT_STRING
+# define RFH_ARG4_TYPE         PRXSTRING
+# define RRFE_ARG0_TYPE        CONSTANT_STRING
+# define RRFE_ARG1_TYPE        REXXPFN
+# define RRFD_ARG0_TYPE        CONSTANT_STRING
+# define RRFD_ARG1_TYPE        CONSTANT_STRING
+# define RRFD_ARG2_TYPE        CONSTANT_STRING
+# define RDF_ARG0_TYPE         CONSTANT_STRING
+# define REH_RETURN            int REXXENTRY
+# define REH_RETURN_TYPE       int
+# define REH_ARG0_TYPE         int
+# define REH_ARG1_TYPE         int
+# define REH_ARG2_TYPE         PEXIT
+# define RREE_ARG0_TYPE        CONSTANT_STRING
+# define RREE_ARG1_TYPE        REXXPFN
+# define RREE_ARG2_TYPE        CONSTANT_STRING
+# define RRED_ARG0_TYPE        CONSTANT_STRING
+# define RRED_ARG1_TYPE        CONSTANT_STRING
+# define RRED_ARG2_TYPE        CONSTANT_STRING
+# define RRED_ARG3_TYPE        CONSTANT_STRING
+# define RRED_ARG4_TYPE        size_t
+# define RSH_RETURN            RexxReturnCode REXXENTRY
+# define RSH_RETURN_TYPE       RexxReturnCode
+# define RSH_ARG0_TYPE         PCONSTRXSTRING
+# define RSH_ARG1_TYPE         unsigned short *
+# define RSH_ARG2_TYPE         PRXSTRING
+# define RRSE_ARG0_TYPE        CONSTANT_STRING
+# define RRSE_ARG1_TYPE        REXXPFN
+# define RRSE_ARG2_TYPE        CONSTANT_STRING
+# define RRSD_ARG0_TYPE        CONSTANT_STRING
+# define RRSD_ARG1_TYPE        CONSTANT_STRING
+# define RRSD_ARG2_TYPE        CONSTANT_STRING
+# define RRSD_ARG3_TYPE        CONSTANT_STRING
+# define RRSD_ARG4_TYPE        size_t
+# define RDE_ARG0_TYPE         CONSTANT_STRING
+# define RDE_ARG1_TYPE         CONSTANT_STRING
+# define RDS_ARG0_TYPE         CONSTANT_STRING
+# define RDS_ARG1_TYPE         CONSTANT_STRING
+# define RS_ARG0_TYPE          size_t
+# define RS_ARG1_TYPE          PCONSTRXSTRING
+# define RS_ARG2_TYPE          CONSTANT_STRING
+# define RS_ARG3_TYPE          PRXSTRING
+# define RS_ARG4_TYPE          CONSTANT_STRING
+# define RS_ARG5_TYPE          int
+# define RS_ARG6_TYPE          PRXSYSEXIT
+# define RS_ARG7_TYPE          short *
+# define RS_ARG8_TYPE          PRXSTRING
+/*
+ * ooRexx 4.0 also removed the following #defines :-(
+ */
+# define REXXALLOCATEMEMORY    RexxAllocateMemory
+# define REXXFREEMEMORY        RexxFreeMemory
+
 #elif defined(USE_OREXX) || defined(USE_OOREXX)
 # define RXSTRING_STRPTR_TYPE PCH
 # define RFH_RETURN           ULONG APIENTRY
