@@ -145,8 +145,10 @@
 #define arexx_writeln                __regina_arexx_writeln
 #define argv0                        __regina_argv0
 #define atopos                       __regina_atopos
+#define atoposrx64                   __regina_atoposrx64
 #define atoposorzero                 __regina_atoposorzero
 #define atozpos                      __regina_atozpos
+#define atozposrx64                  __regina_atozposrx64
 #define basedays                     __regina_basedays
 #define bmstrstr                     __regina_bmstrstr
 #define buildtinfunc                 __regina_buildtinfunc
@@ -395,6 +397,7 @@
 #define restore_variable_state       __regina_restore_variable_state
 #define retlength                    __regina_retlength
 #define retvalue                     __regina_retvalue
+#define rex_getcallstack             __regina_rex_getcallstack
 #define rex_gciprefixchar            __regina_rex_gciprefixchar
 #define rex_lower                    __regina_rex_lower
 #define rex_poolid                   __regina_rex_poolid
@@ -406,6 +409,7 @@
 #define rex_rxqueue                  __regina_rex_rxqueue
 #define rex_userid                   __regina_rex_userid
 #define run_popen                    __regina_run_popen
+#define rx64_to_streng               __regina_rx64_to_streng
 #define set_err_message              __regina_set_err_message
 #define send_command_to_rxstack      __regina_send_command_to_rxstack
 #define setGlobalTSD                 __regina_setGlobalTSD
